==> python-fmrest-1.0.2.tar.gz: python-fmrest-1.0.2/fmrest/exceptions.py <==
class FMRestException(Exception):
    """The base fmrest Exception."""

class RequestException(FMRestException):
    """Exception for http request errors

    Re-raised after requests module exception
    """

    def __init__(self, original_exception, request_args, request_kwargs):
        """Parameters
        ----------
        original_exception
            The original exception raised by requests module
        request_args
            Args to the request function
        request_kwargs
            Keyword args to the request function
        """

        self._original_exception = original_exception
        self._request_args = request_args
        self._request_kwargs = request_kwargs
        super().__init__('Request error: {}'.format(original_exception))

class ResponseException(FMRestException):
    """Exception for http response errors

    Re-raised after requests module exception
    """

    def __init__(self, original_exception, response):
        """Parameters
        ----------
        original_exception
            The original exception raised by requests module
        response:
            Response object of requests module
        """
        self._response = response
        super().__init__(
            '{}, {} http response, content-type: {}'.format(
                original_exception,
                self._response.status_code,
                self._response.headers.get('content-type', None))
        )

class BadJSON(ResponseException):
    """Invalid json response"""

class FileMakerError(FMRestException):
    """Error raised by FileMaker Data API"""

    def __init__(self, error_code, error_message):
        super().__init__('FileMaker Server returned error {}, {}'.format(error_code, error_message))

class RecordError(FMRestException):
    """Error with the local Record instance."""

==> python-fmrest-1.7.5.tar.gz: python-fmrest-1.7.5/fmrest/exceptions.py <==
from typing import Optional, Any
import requests

class FMRestException(Exception):
    """The base fmrest Exception."""

class RequestException(FMRestException):
    """Exception for http request errors

    Re-raised after requests module exception
    """

    def __init__(self, original_exception: Exception, request_args: Any, request_kwargs: Any) -> None:
        """Parameters
        ----------
        original_exception
            The original exception raised by requests module
        request_args
            Args to the request function
        request_kwargs
            Keyword args to the request function
        """

        self._original_exception = original_exception
        self._request_args = request_args
        self._request_kwargs = request_kwargs
        super().__init__('Request error: {}'.format(original_exception))

class ResponseException(FMRestException):
    """Exception for http response errors

    Re-raised after requests module exception
    """

    def __init__(self, original_exception: Exception, response: requests.Response) -> None:
        """Parameters
        ----------
        original_exception
            The original exception raised by requests module
        response:
            Response object of requests module
        """
        self._response = response
        super().__init__(
            '{}, {} http response, content-type: {}'.format(
                original_exception,
                self._response.status_code,
                self._response.headers.get('content-type', None))
        )

class BadJSON(ResponseException):
    """Invalid json response"""

class FileMakerError(FMRestException):
    """Error raised by FileMaker Data API"""

    def __init__(self, error_code: Optional[int], error_message: str) -> None:
        super().__init__('FileMaker Server returned error {}, {}'.format(error_code, error_message))


class BadGatewayError(FMRestException):
    """Exception for Bad Gateway errors from FMS's web server.
    Usually, this happens when the web server is running, but the Data API is
    not enabled or not responding.
    """


class RecordError(FMRestException):
    """Error with the local Record instance."""
